module.exports = function(RED) {
  "use strict";

  var conf = require('router').configuration;
  var util = require('util');

  function ConfigurationGetNode(n) {
    RED.nodes.createNode(this, n);

    var node = this;

    this.key = n.key;
    this.keyType = n.keyType;

    this.on("input", (msg) => {
      let key = RED.util.evaluateNodeProperty(node.key, node.keyType, node, msg) || '';
      if (key) {
        msg.payload = conf[key];
      }
      node.send(msg);
    });
  }

  function ConfigurationSetNode(n) {
    RED.nodes.createNode(this, n);

    var node = this;

    this.key = n.key;
    this.keyType = n.keyType;
    this.value = n.value;
    this.valueType = n.valueType;

    node.on("input", (msg) => {
      let key = RED.util.evaluateNodeProperty(node.key, node.keyType, node, msg) || '';
      let value = RED.util.evaluateNodeProperty(node.value, node.valueType, node, msg) || '';
      if (key) {
        try {
          conf[key] = value;
        } catch(err) {
          node.error(util.format("Setting configuration “%s” failed: %s", key, err.message), msg);
        }
      }
      node.send(msg);
    });
  }

  RED.nodes.registerType("conf-get", ConfigurationGetNode);
  RED.nodes.registerType("conf-set", ConfigurationSetNode);
}
